@@ -2,12 +2,12 @@ from pychonet.EchonetInstance import EchonetInstance
 
 class HomeSolarPower(EchonetInstance):
     def __init__(self, host, api_connector, instance = 0x1):
-        self.eojgc = 0x02
-        self.eojcc = 0x79
+        self._eojgc = 0x02
+        self._eojcc = 0x79
         EchonetInstance.__init__(self, host, self._eojgc, self._eojcc, instance, api_connector)
 
     def getMeasuredInstantPower(self):
-        return int.from_bytes(self.getMessage(0xE0), 'big')
+        return self.getMessage(0xE0)
 
     def getMeasuredCumulPower(self):
-        return int.from_bytes(self.getMessage(0xE1), 'big')
+        return self.getMessage(0xE1)
